gchecky.model.item_t

Package gchecky :: Module model :: Class item_t |
[hide private]
[frames] | no frames]

# Class item_t

source code

    object --+
             |
     gxml.Node --+
                 |
                item_t

    >>> test_node(item_t(name='Peter', description='The Great', unit_price=price_t(value=1, currency='GBP'), quantity=1, merchant_item_id='custom_merchant_item_id',
    ...                  merchant_private_item_data=['some', {'private':'data', 'to':['test','the'],'thing':None}, '!! Numbers: ', None, False, True, [11, 12., [13.4]]])
    ...          )
    >>> test_node(item_t(name='Name with empty description', description='', unit_price=price_t(value=1, currency='GBP'), quantity=1))

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| name = `String:PATH(item-name):REQ:EMPTY`
| description = `String:PATH(item-description):REQ:EMPTY`
| unit_price = `Node:PATH(unit-price):REQ:{ price_t }`
| quantity = `Decimal:PATH(quantity):REQ`
| item_weight = `Node:PATH(item-weight):OPT:{ item_weight_t }`
| merchant_item_id = `String:PATH(merchant-item-id):OPT:EMPTY`
| tax_table_selector = `String:PATH(tax-table-selector):OPT:EMPTY`
| digital_content = `Node:PATH(digital-content):OPT:{ digital_con`...``
| merchant_private_item_data = `Any:PATH(merchant-private-item-da`...``
| _fields = ``{``'``description``'``:` String:PATH(item-description):REQ:EM`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### digital_content Value:
      Node:PATH(digital-content):OPT:{ digital_content_t }

  ### merchant_private_item_data Value:
      Any:PATH(merchant-private-item-data):OPT

  ### _fields list of meta-Fields of this class. Value:
      {'description': String:PATH(item-description):REQ:EMPTY,
       'digital_content': Node:PATH(digital-content):OPT:{ digital_content_t
       },
       'item_weight': Node:PATH(item-weight):OPT:{ item_weight_t },
       'merchant_item_id': String:PATH(merchant-item-id):OPT:EMPTY,
       'merchant_private_item_data': Any:PATH(merchant-private-item-data):OP
      T,
       'name': String:PATH(item-name):REQ:EMPTY,
      ...